@@ -2,14 +2,16 @@ package App::ForkProve;
 
 use strict;
 use 5.008_001;
-use version; our $VERSION = "v0.4.8";
+use version; our $VERSION = "v0.4.9";
 
 use App::Prove;
 use Getopt::Long ':config' => qw(bundling pass_through no_ignore_case);
+use Scalar::Util 'openhandle';
 
 use App::ForkProve::SourceHandler;
 
 our @Blacklists = qw( Test::SharedFork );
+our %Data;
 
 sub run {
     my($class, @args) = @_;
@@ -50,6 +52,23 @@ sub run {
         $module->import(@import);
     }
 
+    for my $loaded (keys %INC) {
+        next unless $loaded =~ /\.pm$/;
+
+        my $mod = $loaded;
+        $mod =~ s{/}{::}g;
+        $mod =~ s{\.pm$}{};
+
+        my $fh = do {
+            no strict 'refs';
+            *{ $mod . '::DATA' }
+        };
+
+        $Data{$mod} = [!!openhandle($fh), $INC{$loaded}];
+        push @{ $Data{$mod} }, tell($fh)
+            if $Data{$mod}[0];
+    }
+
     my $app = App::Prove->new;
     $app->process_args(@ARGV);
     $app->run;
